@@ -27,7 +27,26 @@ DEFAULT_ENER_UP_INT: int = 21600
 
 
 def object_factory(dev_type, config, manager) -> Tuple[str, VeSyncBaseDevice]:
-    """Get device type and instantiate class."""
+    """Get device type and instantiate class.
+
+    Pulls the device types from each module to determine the type of device and
+    instantiates the device object.
+
+    Args:
+        dev_type (str): Device model type returned from API
+        config (dict): Device configuration from `VeSync.get_devices()` API call
+        manager (VeSync): VeSync manager object
+
+    Returns:
+        Tuple[str, VeSyncBaseDevice]: Tuple of device type classification and
+        instantiated device object
+
+    Note:
+        Device types are pulled from the `*_mods` attribute of each device module.
+        See [pyvesync.vesyncbulb.bulb_mods], [pyvesync.vesyncfan.fan_mods],
+        [pyvesync.vesyncoutlet.outlet_mods], [pyvesync.vesyncswitch.switch_mods],
+        and [pyvesync.vesynckitchen.kitchen_mods] for more information.
+    """
     def fans(dev_type, config, manager):
         fan_cls = fan_mods.fan_modules[dev_type]  # noqa: F405
         fan_obj = getattr(fan_mods, fan_cls)
@@ -74,10 +93,51 @@ def object_factory(dev_type, config, manager) -> Tuple[str, VeSyncBaseDevice]:
 
 
 class VeSync:  # pylint: disable=function-redefined
-    """VeSync API functions."""
+    """VeSync Manager Class."""
 
-    def __init__(self, username, password, time_zone=DEFAULT_TZ, debug=False):
-        """Initialize VeSync class with username, password and time zone."""
+    def __init__(self, username, password, time_zone=DEFAULT_TZ,
+                 debug=False, redact=True):
+        """Initialize VeSync Manager.
+
+        This class is used as the manager for all VeSync objects, all methods and
+        API calls are performed from this class. Time zone, debug and redact are
+        optional. Time zone must be a string of an IANA time zone format. Once
+        class is instantiated, call `manager.login()` to log in to VeSync servers,
+        which returns `True` if successful. Once logged in, call `manager.update()`
+        to retrieve devices and update device details.
+
+        Parameters:
+            username : str
+                VeSync account username (usually email address)
+            password : str
+                VeSync account password
+            time_zone : str, optional
+                Time zone for device from IANA database, by default DEFAULT_TZ
+            debug : bool, optional
+                Enable debug logging, by default False
+            redact : bool, optional
+                Redact sensitive information in logs, by default True
+
+        Attributes:
+            fans : list
+                List of VeSyncFan objects for humidifiers and air purifiers
+            outlets : list
+                List of VeSyncOutlet objects for smart plugs
+            switches : list
+                List of VeSyncSwitch objects for wall switches
+            bulbs : list
+                List of VeSyncBulb objects for smart bulbs
+            kitchen : list
+                List of VeSyncKitchen objects for smart kitchen appliances
+            dev_list : dict
+                Dictionary of device lists
+            token : str
+                VeSync API token
+            account_id : str
+                VeSync account ID
+            enabled : bool
+                True if logged in to VeSync, False if not
+        """
         self.debug = debug
         if debug:  # pragma: no cover
             logger.setLevel(logging.DEBUG)
@@ -87,6 +147,9 @@ class VeSync:  # pylint: disable=function-redefined
             fan_mods.logger.setLevel(logging.DEBUG)
             helpermodule.logger.setLevel(logging.DEBUG)
             kitchen_mods.logger.setLevel(logging.DEBUG)
+        self._redact = redact
+        if redact:
+            self.redact = redact
         self.username = username
         self.password = password
         self.token = None
@@ -150,6 +213,20 @@ class VeSync:  # pylint: disable=function-redefined
                 m.logger.setLevel(logging.WARNING)
         self._debug = new_flag
 
+    @property
+    def redact(self) -> bool:
+        """Return debug flag."""
+        return self._redact
+
+    @redact.setter
+    def redact(self, new_flag: bool) -> None:
+        """Set debug flag."""
+        if new_flag:
+            Helpers.shouldredact = True
+        elif new_flag is False:
+            Helpers.shouldredact = False
+        self._redact = new_flag
+
     @property
     def energy_update_interval(self) -> int:
         """Return energy update interval."""
@@ -225,7 +302,11 @@ class VeSync:  # pylint: disable=function-redefined
         return devices
 
     def process_devices(self, dev_list: list) -> bool:
-        """Instantiate Device Objects."""
+        """Instantiate Device Objects.
+
+        Internal method run by `get_devices()` to instantiate device objects.
+
+        """
         devices = VeSync.set_dev_id(dev_list)
 
         num_devices = 0
@@ -263,7 +344,10 @@ class VeSync:  # pylint: disable=function-redefined
         return True
 
     def get_devices(self) -> bool:
-        """Return tuple listing outlets, switches, and fans of devices."""
+        """Return tuple listing outlets, switches, and fans of devices.
+
+        This is an internal method called by `update()`
+        """
         if not self.enabled:
             return False
 
@@ -290,7 +374,13 @@ class VeSync:  # pylint: disable=function-redefined
         return proc_return
 
     def login(self) -> bool:
-        """Return True if log in request succeeds."""
+        """Log into VeSync server.
+
+        Username and password are provided when class is instantiated.
+
+        Returns:
+            True if login successful, False if not
+        """
         user_check = isinstance(self.username, str) and len(self.username) > 0
         pass_check = isinstance(self.password, str) and len(self.password) > 0
         if user_check is False:
@@ -320,15 +410,18 @@ class VeSync:  # pylint: disable=function-redefined
 
     def device_time_check(self) -> bool:
         """Test if update interval has been exceeded."""
-        if (
+        return (
             self.last_update_ts is None
             or (time.time() - self.last_update_ts) > self.update_interval
-        ):
-            return True
-        return False
+        )
 
     def update(self) -> None:
-        """Fetch updated information about devices."""
+        """Fetch updated information about devices.
+
+        Pulls devices list from VeSync and instantiates any new devices. Devices
+        are stored in the instance attributes `outlets`, `switches`, `fans`, and
+        `bulbs`. The `_device_list` attribute is a dictionary of these attributes.
+        """
         if self.device_time_check():
 
             if not self.enabled:
@@ -345,13 +438,13 @@ class VeSync:  # pylint: disable=function-redefined
             self.last_update_ts = time.time()
 
     def update_energy(self, bypass_check=False) -> None:
-        """Fetch updated energy information about devices."""
+        """Fetch updated energy information for outlet devices."""
         if self.outlets:
             for outlet in self.outlets:
                 outlet.update_energy(bypass_check)
 
     def update_all_devices(self) -> None:
-        """Run get_details() for each device."""
-        devices = list(self._dev_list.keys())
+        """Run `get_details()` for each device and update state."""
+        devices = list(self._dev_list.values())
         for dev in chain(*devices):
-            dev.get_details()
+            dev.update()
