@@ -21,6 +21,8 @@ outlet_config = {
         'module': 'VeSyncOutlet15A'},
     'ESO15-TB': {
         'module': 'VeSyncOutdoorPlug'},
+    'BSDOG01': {
+        'module': 'VeSyncOutletBSDGO1'},
 }
 
 outlet_modules = {k: v['module'] for k, v in outlet_config.items()}
@@ -134,7 +136,7 @@ class VeSyncOutlet(VeSyncBaseDevice):
     def display(self):
         """Return formatted device info to stdout."""
         super().display()
-        disp1 = [
+        disp = [
             ('Active Time : ', self.active_time, ' minutes'),
             ('Energy: ', self.energy_today, ' kWh'),
             ('Power: ', self.power, ' Watts'),
@@ -143,8 +145,8 @@ class VeSyncOutlet(VeSyncBaseDevice):
             ('Energy Month: ', self.monthly_energy_total, ' kWh'),
             ('Energy Year: ', self.yearly_energy_total, ' kWh'),
         ]
-        for line in disp1:
-            print(f'{line[0]:.<15} {line[1]} {line[2]}')
+        for line in disp:
+            print(f'{line[0]:.<30} {line[1]} {line[2]}')
 
     def displayJSON(self):
         """Return JSON details for outlet."""
@@ -162,7 +164,7 @@ class VeSyncOutlet(VeSyncBaseDevice):
             }
         )
 
-        return sup_val
+        return json.dumps(sup_val, indent=4)
 
 
 class VeSyncOutlet7A(VeSyncOutlet):
@@ -308,7 +310,7 @@ class VeSyncOutlet10A(VeSyncOutlet):
             '/10a/v1/device/devicedetail',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(r):
@@ -329,7 +331,7 @@ class VeSyncOutlet10A(VeSyncOutlet):
             '/10a/v1/device/configurations',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(r):
@@ -346,7 +348,7 @@ class VeSyncOutlet10A(VeSyncOutlet):
             '/10a/v1/device/energyweek',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -363,7 +365,7 @@ class VeSyncOutlet10A(VeSyncOutlet):
             '/10a/v1/device/energymonth',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -380,7 +382,7 @@ class VeSyncOutlet10A(VeSyncOutlet):
             '/10a/v1/device/energyyear',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -398,7 +400,7 @@ class VeSyncOutlet10A(VeSyncOutlet):
             '/10a/v1/device/devicestatus',
             'put',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -417,7 +419,7 @@ class VeSyncOutlet10A(VeSyncOutlet):
             '/10a/v1/device/devicestatus',
             'put',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -445,7 +447,7 @@ class VeSyncOutlet15A(VeSyncOutlet):
             '/15a/v1/device/devicedetail',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         attr_list = (
@@ -479,7 +481,7 @@ class VeSyncOutlet15A(VeSyncOutlet):
             '/15a/v1/device/configurations',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(r):
@@ -496,7 +498,7 @@ class VeSyncOutlet15A(VeSyncOutlet):
             '/15a/v1/device/energyweek',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -513,7 +515,7 @@ class VeSyncOutlet15A(VeSyncOutlet):
             '/15a/v1/device/energymonth',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -530,7 +532,7 @@ class VeSyncOutlet15A(VeSyncOutlet):
             '/15a/v1/device/energyyear',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -548,7 +550,7 @@ class VeSyncOutlet15A(VeSyncOutlet):
             '/15a/v1/device/devicestatus',
             'put',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -567,13 +569,12 @@ class VeSyncOutlet15A(VeSyncOutlet):
             '/15a/v1/device/devicestatus',
             'put',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
             self.device_status = 'off'
             return True
-
         logger.warning('Error turning %s off', self.device_name)
         return False
 
@@ -587,7 +588,7 @@ class VeSyncOutlet15A(VeSyncOutlet):
             '/15a/v1/device/nightlightstatus',
             'put',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -605,7 +606,7 @@ class VeSyncOutlet15A(VeSyncOutlet):
             '/15a/v1/device/nightlightstatus',
             'put',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -629,7 +630,7 @@ class VeSyncOutdoorPlug(VeSyncOutlet):
             '/outdoorsocket15a/v1/device/devicedetail',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(r):
@@ -655,7 +656,7 @@ class VeSyncOutdoorPlug(VeSyncOutlet):
             '/outdoorsocket15a/v1/device/configurations',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(r):
@@ -671,7 +672,7 @@ class VeSyncOutdoorPlug(VeSyncOutlet):
             '/outdoorsocket15a/v1/device/energyweek',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -688,7 +689,7 @@ class VeSyncOutdoorPlug(VeSyncOutlet):
             '/outdoorsocket15a/v1/device/energymonth',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -704,7 +705,7 @@ class VeSyncOutdoorPlug(VeSyncOutlet):
             '/outdoorsocket15a/v1/device/energyyear',
             'post',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -723,7 +724,7 @@ class VeSyncOutdoorPlug(VeSyncOutlet):
             '/outdoorsocket15a/v1/device/devicestatus',
             'put',
             headers=Helpers.req_headers(self.manager),
-            json=body,
+            json_object=body,
         )
 
         if Helpers.code_check(response):
@@ -733,9 +734,73 @@ class VeSyncOutdoorPlug(VeSyncOutlet):
         return False
 
     def turn_on(self) -> bool:
-        """Turn outdoor outlet on and return True if successful."""
+        """Turn on outlet."""
         return bool(self.toggle('on'))
 
     def turn_off(self) -> bool:
-        """Turn outdoor outlet off and return True if successful."""
+        """Turn off outlet."""
         return bool(self.toggle('off'))
+
+
+class VeSyncOutletBSDGO1(VeSyncOutlet):
+    """VeSync BSDGO1 smart plug."""
+
+    def __init__(self, details, manager):
+        """Initialize BSDGO1 smart plug class."""
+        super().__init__(details, manager)
+
+    def get_details(self) -> None:
+        """Get BSDGO1 device details."""
+        body = Helpers.req_body(self.manager, 'bypassV2')
+        body['cid'] = self.cid
+        body['configModule'] = self.config_module
+        body['payload'] = {
+            'method': 'getProperty',
+            'source': 'APP',
+            'data': {}
+        }
+
+        r, _ = Helpers.call_api(
+            '/cloud/v2/deviceManaged/bypassV2',
+            'post',
+            headers=Helpers.req_header_bypass(),
+            json_object=body,
+        )
+
+        if Helpers.code_check(r):
+            self.device_status = 'on' if r.get('result', {}).get(
+                'powerSwitch_1') == 1 else 'off'
+        else:
+            logger.debug('Error getting %s details', self.device_name)
+
+    def turn_on(self) -> bool:
+        """Turn BSDGO1 outlet on."""
+        return self._set_power(True)
+
+    def turn_off(self) -> bool:
+        """Turn BSDGO1 outlet off."""
+        return self._set_power(False)
+
+    def _set_power(self, power: bool) -> bool:
+        """Set power state of BSDGO1 outlet."""
+        body = Helpers.req_body(self.manager, 'bypassV2')
+        body['cid'] = self.cid
+        body['configModule'] = self.config_module
+        body['payload'] = {
+            'data': {'powerSwitch_1': 1 if power else 0},
+            'method': 'setProperty',
+            'source': 'APP'
+        }
+
+        r, _ = Helpers.call_api(
+            '/cloud/v2/deviceManaged/bypassV2',
+            'post',
+            headers=Helpers.req_header_bypass(),
+            json_object=body,
+        )
+
+        if Helpers.code_check(r):
+            self.device_status = 'on' if power else 'off'
+            return True
+        logger.warning('Error turning %s %s', self.device_name, 'on' if power else 'off')
+        return False
